@@ -6,6 +6,8 @@ def node_decorator(*args, **kwargs):
         class NewCls(cls):
             def __init__(self):
                 self.cls = cls
+                self.name = ''
+                self.title = ''
                 self.color = ''
                 self.icon = ''
                 self.editor = None
