@@ -108,13 +108,13 @@ class Spec:
                         }
 
                         if input.customScope:
-                            inObject.customScope = True
+                            inObject['customScope'] = True
                         if input.messageScope:
-                            inObject.messageScope = True
+                            inObject['messageScope'] = True
                         if input.messageOnly:
-                            inObject.messageOnly = True
+                            inObject['messageOnly'] = True
                         if input.pyScope:
-                            inObject.pyScope = True
+                            inObject['pyScope'] = True
 
                         name = Spec.lower_first_letter(input.name)
                         inProperties[name] = inObject
@@ -174,9 +174,9 @@ class Spec:
                         }
 
                         if output.messageScope:
-                            outObject.messageScope = True
+                            outObject['messageScope'] = True
                         if output.messageOnly:
-                            outObject.messageOnly = True
+                            outObject['messageOnly'] = True
 
                         name = Spec.lower_first_letter(output.name)
                         outProperties[name] = outObject
@@ -236,13 +236,13 @@ class Spec:
                         }
 
                         if option.customScope:
-                            optObject.customScope = True
+                            optObject['customScope'] = True
                         if option.messageScope:
-                            optObject.messageScope = True
+                            optObject['messageScope'] = True
                         if option.messageOnly:
-                            optObject.messageOnly = True
+                            optObject['messageOnly'] = True
                         if option.pyScope:
-                            optObject.pyScope = True
+                            optObject['pyScope'] = True
 
                         name = Spec.lower_first_letter(option.name)
                         optProperties[name] = optObject
